@@ -247,6 +247,32 @@ get_identity_sync (GoaOAuth2Provider  *provider,
   return ret;
 }
 
+/* ---------------------------------------------------------------------------------------------------- */
+
+static gboolean
+is_deny_node (GoaOAuth2Provider *provider, WebKitDOMNode *node)
+{
+  WebKitDOMHTMLButtonElement *button_element;
+  gboolean ret;
+  gchar *name;
+
+  name = NULL;
+  ret = FALSE;
+
+  if (!WEBKIT_DOM_IS_HTML_BUTTON_ELEMENT (node))
+    goto out;
+
+  button_element = WEBKIT_DOM_HTML_BUTTON_ELEMENT (node);
+  name = webkit_dom_html_button_element_get_name (button_element);
+  if (g_strcmp0 (name, "cancel_clicked") != 0)
+    goto out;
+
+  ret = TRUE;
+
+ out:
+  g_free (name);
+  return ret;
+}
 
 /* ---------------------------------------------------------------------------------------------------- */
 
@@ -379,6 +405,7 @@ goa_facebook_provider_class_init (GoaFacebookProviderClass *klass)
   oauth2_class->get_client_secret        = get_client_secret;
   oauth2_class->get_authentication_cookie = get_authentication_cookie;
   oauth2_class->get_identity_sync        = get_identity_sync;
+  oauth2_class->is_deny_node             = is_deny_node;
   oauth2_class->get_use_external_browser = get_use_external_browser;
   oauth2_class->add_account_key_values   = add_account_key_values;
 }
