@@ -222,13 +222,15 @@ goa_web_view_init (GoaWebView *self)
   session = webkit_get_default_session ();
 
   soup_session_add_feature_by_type (session, SOUP_TYPE_PROXY_RESOLVER_GNOME);
+  g_object_set (session, "accept-language-auto", TRUE, NULL);
 
   soup_session_remove_feature_by_type (session, SOUP_TYPE_COOKIE_JAR);
   cookie_jar = soup_cookie_jar_new ();
   soup_session_add_feature (session, SOUP_SESSION_FEATURE (cookie_jar));
   g_object_unref (cookie_jar);
 
-  gtk_widget_set_name (GTK_WIDGET (self), "goa-overlay");
+  gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET (self)),
+                               GTK_STYLE_CLASS_OSD);
 
   scrolled_window = gtk_scrolled_window_new (NULL, NULL);
   gtk_widget_set_size_request (scrolled_window, 500, 400);
@@ -250,7 +252,6 @@ goa_web_view_init (GoaWebView *self)
   gtk_overlay_add_overlay (GTK_OVERLAY (self), priv->floating_bar);
 
   priv->progress_bar = gtk_progress_bar_new ();
-  gtk_widget_set_name (priv->progress_bar, "goa-progress-bar");
   gtk_widget_set_halign (priv->progress_bar, GTK_ALIGN_FILL);
   gtk_widget_set_valign (priv->progress_bar, GTK_ALIGN_START);
   gtk_overlay_add_overlay (GTK_OVERLAY (self), priv->progress_bar);
@@ -287,3 +288,29 @@ goa_web_view_get_view (GoaWebView *self)
 {
   return self->priv->web_view;
 }
+
+void
+goa_web_view_fake_mobile (GoaWebView *self)
+{
+  WebKitWebSettings *settings;
+
+  settings = webkit_web_view_get_settings (WEBKIT_WEB_VIEW (self->priv->web_view));
+
+  /* This is based on the HTC Wildfire's user agent. Some
+   * providers, like Google, refuse to provide the mobile
+   * version of their authentication pages otherwise. eg.,
+   * in Google's case, passing btmpl=mobile does not help.
+   *
+   * The actual user agent used by a HTC Wildfire is:
+   * Mozilla/5.0 (Linux; U; Android 2.2.1; en-us; HTC Wildfire
+   * Build/FRG83D) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0
+   * Mobile Safari/533.1
+   *
+   * Also note that the user agents of some mobile browsers may
+   * not work. eg., Nokia N9.
+   */
+  g_object_set (G_OBJECT (settings),
+                "user-agent", "Mozilla/5.0 (GNOME; not Android) "
+                              "AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile",
+                NULL);
+}
